@@ -27,11 +27,15 @@ sub new {
     my $dir = File::Temp::tempdir( CLEANUP => 1 );
 
     my $pid = fork or do {
+        diag "forked to $$";
+
         local $SIG{'CHLD'};
 
         my $ok = eval {
             MyServer::HTTP->run(
                 port => 0,
+                server_type => 'Single',
+                # log_level => 4,
                 my_tempdir => $dir,
             );
 
@@ -44,7 +48,7 @@ sub new {
 
     my $port;
 
-    diag "Waiting for process $pid to tell us which port it’s bound to …";
+    diag "PID $$ ($0): Waiting for process $pid to tell us which port it’s bound to …";
 
     while (!$port) {
         select( undef, undef, undef, 0.1 );
